@@ -22,6 +22,8 @@
 #include <kapp.h>
 #include <stdlib.h>
 #include <kstddirs.h>
+#include <kxaim.h>
+
 kxContact *kxContact::myC=0L;
 
 kxContact::kxContact(){
@@ -33,6 +35,8 @@ kxContact::kxContact(){
 
   contactList.setAutoDelete(TRUE);
   ignoreList.setAutoDelete(TRUE);
+  groupList.setAutoDelete(TRUE);
+  nonICQIDcount=0;
 }
 
 kxContact::~kxContact(){
@@ -42,6 +46,7 @@ void kxContact::init()
 {
 	unknownMessage=0;
 	loadContacts();
+	loadGroups();
 }
 
 int kxContact::countShow()
@@ -64,7 +69,7 @@ int kxContact::countIgnore()
 }
 
 
-bool kxContact::add(const char *nick, UIN uin, bool auth, bool show)
+bool kxContact::add(QString nick, UIN uin, bool auth, bool show)
 {
   bool oldShow=FALSE;
   kxContactStruct *c=NULL;
@@ -124,13 +129,14 @@ bool kxContact::add(const char *nick, UIN uin, bool auth, bool show)
   	}
   }
 
- 	strcpy(c->nick, _nick.latin1());
+ 	c->nick=_nick;
  	c->uin=uin;
  	c->mySocket=NULL;
  	c->status=STATUS_OFFLINE;
  	c->alwaysServer=FALSE;
  	c->invisible=0;
  	c->visible=0;
+ 	c->groupID=0;
  	c->waitAuth=auth;
  	c->unreadMessages=0;
  	c->ignore=FALSE;
@@ -138,6 +144,11 @@ bool kxContact::add(const char *nick, UIN uin, bool auth, bool show)
  	c->show=show;
  	c->sendWidget=NULL;
  	c->ignoreAway=FALSE;
+ 	c->tcpVersion=0;
+ 	c->fg=QColor(0,0,0);
+ 	c->bg=QColor(0xFF,0xFF,0xFF); 	
+ 	c->needAuth=FALSE;		 	
+
  	if (!oldShow) contactList.append(c);
   if (show)
   {		
@@ -150,7 +161,68 @@ bool kxContact::add(const char *nick, UIN uin, bool auth, bool show)
  	return TRUE;
 }
 
-bool kxContact::ignoreAdd(UIN uin, char *nick)
+UIN kxContact::addNonICQ(QString _nick, QString _gsm)
+{
+  kxContactStruct *c=NULL;
+
+	UIN uin=100+(++nonICQIDcount);
+
+	c=new kxContactStruct;
+	unsigned int cnt=0;
+	QStrList tmp;
+ 	contactsFile->setGroup("Default");
+
+ 	contactsFile->readListEntry("Contacts",tmp);
+ 	QString tmpUin;
+ 	tmpUin.sprintf("%d",uin);
+ 	tmp.append(tmpUin);
+ 	cnt=contactsFile->readNumEntry("Count",0);
+ 	cnt++;
+ 	QString str;
+ 	str.sprintf("Contact %d",uin);
+ 	contactsFile->setGroup(str);
+ 	contactsFile->writeEntry("Nick",_nick);	
+ 	contactsFile->writeEntry("UIN",uin);
+	contactsFile->writeEntry("Non ICQ ID",nonICQIDcount);	
+	contactsFile->writeEntry("Authorized",TRUE);
+	contactsFile->writeEntry("Group", 998);
+   	
+	c->gsm=_gsm;
+ 	contactsFile->writeEntry("Cellular", _gsm);	
+	
+ 	c->authorized=TRUE;
+ 	c->nick=_nick;
+ 	c->uin=uin;
+ 	c->nonICQID=nonICQIDcount;
+ 	c->mySocket=NULL;
+ 	c->status=STATUS_OFFLINE;
+ 	c->alwaysServer=FALSE;
+ 	c->invisible=0;
+ 	c->visible=0;
+ 	c->groupID=998;
+ 	c->waitAuth=FALSE;
+ 	c->unreadMessages=0;
+ 	c->ignore=FALSE;
+ 	c->onlineNotify=FALSE;
+ 	c->show=TRUE;
+ 	c->sendWidget=NULL;
+ 	c->ignoreAway=FALSE;
+ 	c->tcpVersion=0;
+ 	c->fg=QColor(0,0,0);
+ 	c->bg=QColor(0xFF,0xFF,0xFF); 	
+ 	c->needAuth=FALSE;		 	
+
+ 	contactList.append(c);
+  contactsFile->setGroup("Default");	
+  contactsFile->writeEntry("Count",cnt);
+  contactsFile->writeEntry("Contacts",tmp);
+  contactsFile->writeEntry("Non ICQ ID Count",nonICQIDcount);		
+  contactsFile->sync();
+  emit contactAdded(uin, QString(_nick));
+ 	return uin;
+}
+
+bool kxContact::ignoreAdd(UIN uin, QString nick)
 {
   bool add=TRUE;
 	if (countIgnore()>0)
@@ -207,7 +279,7 @@ bool kxContact::ignoreAdd(UIN uin, char *nick)
   		
  	contactsFile->setGroup("Default");	
  	contactsFile->writeEntry("Count",count);
-	contactsFile->writeEntry("Contacts",tmp); 	
+	contactsFile->writeEntry("Contacts",tmp);	
  	contactsFile->sync();
  	return TRUE;
 }
@@ -274,13 +346,13 @@ void kxContact::ignoreRemove(UIN uin)
 	}
 }
 
-void kxContact::rename(UIN uin, const char *_nick)
+void kxContact::rename(UIN uin, QString _nick)
 {
 	for (int t=0; t<count(); t++)
 	{
 		if (contactList.at(t)->uin==uin)
 		{
-			strcpy(contactList.at(t)->nick, _nick);
+			contactList.at(t)->nick=_nick;
 			if (contactList.at(t)->show)
 			{
       	contactsFile->setGroup("Default");
@@ -303,7 +375,7 @@ void kxContact::rename(UIN uin, const char *_nick)
 	{
 		if (ignoreList.at(t)->uin==uin)
 		{
-			strcpy(ignoreList.at(t)->nick, _nick);
+			ignoreList.at(t)->nick=_nick;
     	contactsFile->setGroup("Default");
     	QStrList tmp;
     	contactsFile->readListEntry("Contacts",tmp);
@@ -368,6 +440,8 @@ void kxContact::loadContacts()
 	unsigned int count=contactsFile->readNumEntry("Count",0);
  	QStrList tmp;
  	contactsFile->readListEntry("Contacts",tmp);
+ 	nonICQIDcount=contactsFile->readNumEntry("Non ICQ ID Count",0);
+ 	
   bool ignoreOnly;
 	if (count>0)
 	{
@@ -380,8 +454,9 @@ void kxContact::loadContacts()
     	if (!ignoreOnly) // normal contact
     	{
       	kxContactStruct *c=new kxContactStruct;
-      	strcpy(c->nick,contactsFile->readEntry("Nick").data());
+      	c->nick=contactsFile->readEntry("Nick");
   			c->uin=contactsFile->readUnsignedNumEntry("UIN");
+ 				c->nonICQID=contactsFile->readUnsignedNumEntry("Non ICQ ID",0);  				  				
   			c->invisible=contactsFile->readUnsignedNumEntry("Invisible", 0);
   			c->visible=contactsFile->readUnsignedNumEntry("Visible", 0);
   			c->alwaysServer=contactsFile->readBoolEntry("Always via Server", FALSE);
@@ -390,6 +465,11 @@ void kxContact::loadContacts()
   			c->authorized=contactsFile->readBoolEntry("Authorized", TRUE);
   			c->onlineNotify=contactsFile->readBoolEntry("Online Notify",FALSE);
   			c->show=contactsFile->readBoolEntry("Show",TRUE);
+  			c->gsm=contactsFile->readEntry("Cellular");
+  			c->needAuth=contactsFile->readBoolEntry("Need Auth", FALSE);
+  			c->groupID=contactsFile->readUnsignedNumEntry("Group", 0);
+  			if (c->nonICQID>0 && c->groupID!=998) c->groupID=998;
+  			
   			if (c->invisible>1) c->invisible=0;
   			if (c->visible>1) c->visible=0;
   			c->status=STATUS_OFFLINE;
@@ -397,18 +477,24 @@ void kxContact::loadContacts()
   			c->unreadMessages=0;
   			c->sendWidget=NULL;
  			 	c->ignoreAway=FALSE;
+ 			 	c->tcpVersion=0;
+ 			 	c->intIp=FALSE;
+ 			 	c->handshakeStatus=0;
+ 			 	c->fg=QColor(0,0,0);
+ 			 	c->bg=QColor(0xFF,0xFF,0xFF); 			 	
   			contactList.append(c);
       }
       else // ignore list
       {
         kxContactStruct *c=new kxContactStruct;
-      	strcpy(c->nick,contactsFile->readEntry("Nick").data());
+      	c->nick=contactsFile->readEntry("Nick");
   			c->uin=contactsFile->readUnsignedNumEntry("UIN");
   			c->ignore=contactsFile->readBoolEntry("Ignore", TRUE);
   			ignoreList.append(c);
       }
   	}
 	}
+
 	contactsFile->setGroup("Default");	
 	contactsFile->writeEntry("Count",count);
 	contactsFile->sync();
@@ -460,7 +546,7 @@ void kxContact::updateContact(UIN uin, unsigned int status, Q_UINT32 ip=0, Q_UIN
 				contactList.at(t)->ip=ip;			
 				contactList.at(t)->realIp=realIp;			
 				contactList.at(t)->tcpVersion=tcpVersion;
-				debug("Show IP: %d, mode: %d, version: %02X",ip, mode, tcpVersion);
+//				debug("Show IP: %d, mode: %d, version: %02X",ip, mode, contactList.at(t)->tcpVersion);
 				contactList.at(t)->port=port;
 				contactList.at(t)->mode=mode;				
 				if (contactList.at(t)->onlineNotify && status!=STATUS_OFFLINE)
@@ -480,7 +566,7 @@ void kxContact::updateContact(UIN uin, unsigned int status, Q_UINT32 ip=0, Q_UIN
 	p3=l;
 	l>>=8;
 	p4=l;
-	debug("IP: %02d.%02d.%02d.%02d",p1, p2, p3, p4);
+//	debug("IP: %02d.%02d.%02d.%02d",p1, p2, p3, p4);
 	
 }
 
@@ -655,44 +741,26 @@ char * kxContact::status2str(unsigned int status)
 /** return the status as a INT */
 int kxContact::status2int(unsigned int status)
 {
-  if (status==STATUS_OFFLINE) 				return STATUS_OFFLINE;
-  switch(status & 0x1ff)
-  {
-	  case STATUS_DND: 			
- 	  case STATUS_DND_KXICQ: 	
-	  	return STATUS_DND;
-	  	break;
-	  case STATUS_OCCUPIED_MAC: 	
-	  case STATUS_OCCUPIED: 	
-	  	return STATUS_OCCUPIED;
-	  	break;
-	  case STATUS_NA_99:
-	  case STATUS_NA: 				
-	  	return STATUS_NA;
-	  	break;
-	  case STATUS_AWAY: 			
-	  	return STATUS_AWAY;
-	  	break;
-	  case STATUS_FFC: 			
-	  	return STATUS_FFC;
-	  	break;
-	  case STATUS_ONLINE: 			
-	  	return STATUS_ONLINE;
-	  	break;
-	 	default:
-			return (STATUS_UNKNOWN);
-	  	break;
-	}  
-  return 0;
+	Q_UINT16 st=status;
+  if (st==STATUS_OFFLINE) 				return STATUS_OFFLINE;
+  if (st & 0x0002) return STATUS_DND;
+    else if (st & 0x0004) return STATUS_NA;
+    else if (st & 0x0010) return STATUS_OCCUPIED;
+    else if (st & 0x0020) return STATUS_FFC;
+    else if (st & 0x0001) return STATUS_AWAY;
+    else if (st & 0x0100) return STATUS_INVISIBLE;
+    else return STATUS_ONLINE;
 }
 
 /** update the socket pointer */
-void kxContact::updateSocket(UIN _uin, kxSocket *_ks){
+void kxContact::updateSocket(UIN _uin, KSocket *_ks, Q_UINT32 _tcpVersion=0x0){
 	for (int t=0; t<count(); t++)
 	{
 		if (contactList.at(t)->uin==_uin)
-		{	
+		{			
 			contactList.at(t)->mySocket=_ks;
+			if (_tcpVersion>0)
+				contactList.at(t)->tcpVersion=_tcpVersion;			
 		}
 	}
 }      
@@ -785,7 +853,7 @@ void kxContact::removeMessage(UIN _uin){
 			if (contactList.at(t)->unreadMessages<0)
 			{
 				kc->unreadMessages=0;
-				debug("Unread Messages(%d) < 0 ???",_uin);
+//				debug("Unread Messages(%d) < 0 ???",_uin);
 			}
 			emit repaintContact(_uin);
 			emit recountMessages(_uin);
@@ -795,10 +863,10 @@ void kxContact::removeMessage(UIN _uin){
 	unknownMessage--;
 	if (unknownMessage<0)
 	{
-			debug("Unread Unknown Messages < 0 ???");
+//			debug("Unread Unknown Messages < 0 ???");
 			unknownMessage=0;
 	}
-	debug("Unknown Message: %d",unknownMessage);
+//	debug("Unknown Message: %d",unknownMessage);
 	emit repaintContact(0);
 	emit recountMessages(0);
 }
@@ -904,16 +972,38 @@ bool kxContact::getIntIp(UIN _uin)
   }     
   return FALSE;
 }
+void kxContact::setUnknownContact(UIN _uin, bool _w)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      contactList.at(t)->unknownContact=_w;
+    }
+  }     
+}
+bool kxContact::getUnknownContact(UIN _uin)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      if (contactList.at(t)->unknownContact) return TRUE;
+      else  return FALSE;
+    }
+  }     
+  return FALSE;
+}
 
 kxUpdateContactNick::kxUpdateContactNick(UIN _uin)
 {
   if (ENGINE->loggedOn())
   {
     uin=_uin;
-    QObject::connect(ENGINE->UDP,SIGNAL(receivedInfoReply(Q_UINT16, UIN, char *, char *, char *, char *, Q_UINT8)),
-                      this, SLOT(SlotInfoReply(Q_UINT16, UIN, char *, char *, char *, char *, Q_UINT8)));
+    QObject::connect(ENGINE->AIM,SIGNAL(receivedMetaSearch(Q_UINT16, UIN, QString, QString,QString,QString, Q_UINT8, Q_UINT8, bool)),
+                      this, SLOT(SlotInfoReply(Q_UINT16, UIN, QString, QString,QString,QString, Q_UINT8, Q_UINT8, bool)));
     QObject::connect(&waitTimer, SIGNAL(timeout()), this, SLOT(SlotTimeout()));
-    seq=ENGINE->UDP->sendInfoReply(uin);
+    seq=ENGINE->AIM->sendRequestInfoOnUin(uin);
     waitTimer.start(3600);
   }
   else
@@ -923,12 +1013,333 @@ void kxUpdateContactNick::SlotTimeout()
 {
   delete this;
 }
-void kxUpdateContactNick::SlotInfoReply(Q_UINT16 _seq, UIN _uin, char *nick, char *first, char *last, char *email, Q_UINT8 auth)
+void kxUpdateContactNick::SlotInfoReply(Q_UINT16 _seq, UIN uin, QString nick, QString first,QString last,QString email, Q_UINT8 auth, Q_UINT8 status, bool isLast)
 {
   if (_seq==seq)
   {
-    emit SignalChangeNick(uin,nick);
     ENGINE->CONTACT->rename(uin,nick);
+    ENGINE->SlotContactChange(uin);
+    emit SignalChangeNick(uin,nick);
     delete this;
   }
 }
+
+bool kxContact::isUnknownContact()
+{
+	for (int t=0; t<count(); t++)
+	{
+      if (contactList.at(t)->unknownContact) return TRUE;
+  }     
+  return FALSE;
+}
+bool kxContact::isWaitForAuth()
+{
+	for (int t=0; t<count(); t++)
+	{
+      if (contactList.at(t)->waitAuth) return TRUE;
+  }     
+  return FALSE;
+}
+void kxContact::setHandshakeStatus(UIN _uin, int _s)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      contactList.at(t)->handshakeStatus=_s;
+    }
+  }
+}
+QColor kxContact::getFGColor(UIN _uin)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      return contactList.at(t)->fg;
+    }
+  }
+  return QColor(0,0,0);
+}
+QColor kxContact::getBGColor(UIN _uin)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      return contactList.at(t)->bg;
+    }
+  }
+  return QColor(0xFF, 0xFF, 0xFF);
+}
+void kxContact::setColor(UIN _uin, QColor fg, QColor bg)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      contactList.at(t)->fg=fg;
+      contactList.at(t)->bg=bg;
+    }
+  }
+}
+void kxContact::setGSM(UIN _uin, QString gsm)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+			contactList.at(t)->gsm=gsm;
+	   	QString str;
+    	str.sprintf("Contact %d",_uin);
+    	contactsFile->setGroup(str);
+    	contactsFile->writeEntry("Cellular", gsm);
+			contactsFile->sync();    	
+  		
+			return;
+		}
+	}	
+}
+QString kxContact::getGSM(UIN _uin)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      return contactList.at(t)->gsm;
+    }
+  }
+  return QString::null;
+}
+void kxContact::setNeedAuth(UIN _uin, bool _na)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+			contactList.at(t)->needAuth=_na;
+	   	QString str;
+    	str.sprintf("Contact %d",_uin);
+    	contactsFile->setGroup(str);
+    	contactsFile->writeEntry("Need Auth", _na);
+			contactsFile->sync();    	  		
+			return;
+		}
+	}
+}
+bool kxContact::getNeedAuth(UIN _uin)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+      return contactList.at(t)->needAuth;
+    }
+  }	
+  return FALSE;
+}
+void kxContact::setGroup(UIN _uin, Q_UINT16 grp)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->uin==_uin)
+		{	
+			contactList.at(t)->groupID=grp;
+	   	QString str;
+    	str.sprintf("Contact %d",_uin);
+    	contactsFile->setGroup(str);
+    	contactsFile->writeEntry("Group", grp);
+			contactsFile->sync();    	
+  		
+			return;
+		}
+	}	
+}
+
+int kxContact::addGroup(QString _name)
+{
+//	debug("Add group: %s",_name.latin1());
+	contactsFile->setGroup("Default");
+	
+	QStrList nameList, numList;
+ 	contactsFile->readListEntry("Group Names",nameList);
+ 	contactsFile->readListEntry("Group IDs",numList);
+ 	
+ 	groupIDCount++;
+ 	
+	kxGroupStruct *c;
+	c=new kxGroupStruct;
+	c->name=_name;
+	c->groupID=groupIDCount;
+	groupList.append(c);
+	
+	QString tmp;
+	tmp.sprintf("%d",groupIDCount);
+	nameList.append(_name.utf8());
+	numList.append(tmp);
+	
+	contactsFile->writeEntry("Group Names",nameList);
+	contactsFile->writeEntry("Group IDs",numList);
+	contactsFile->writeEntry("Group ID Count",groupIDCount);		
+	contactsFile->sync();	 	
+}
+void kxContact::removeGroup(Q_UINT16 id)
+{
+	for (int t=0; t<count(); t++)
+	{
+		if (contactList.at(t)->groupID==id)
+		{	
+			setGroup(contactList.at(t)->uin, 0);
+		}
+	}
+	QStrList nameList, numList;
+	groupList.setAutoDelete(TRUE);
+	int del=-1;
+	for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID!=id)
+		{			
+			nameList.append(groupList.at(t)->name);
+			QString num=QString::number(groupList.at(t)->groupID);
+			numList.append(num);		
+		}
+		else del=t;
+	}
+	if (del>=0) groupList.remove(del);
+	
+	contactsFile->setGroup("Default");	
+	contactsFile->writeEntry("Group Names",nameList);
+	contactsFile->writeEntry("Group IDs",numList);
+	contactsFile->sync();	
+}
+void kxContact::renameGroup(Q_UINT16 id, QString name)
+{
+	QStrList nameList, numList;
+	for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID!=id)
+			nameList.append(groupList.at(t)->name);
+		else
+		{
+			nameList.append(name);
+			groupList.at(t)->name=name;
+		}
+		QString num=QString::number(groupList.at(t)->groupID);
+		numList.append(num);
+	}
+	
+	contactsFile->setGroup("Default");	
+	contactsFile->writeEntry("Group Names",nameList);
+	contactsFile->writeEntry("Group IDs",numList);
+	contactsFile->sync();	
+}
+QString kxContact::getGroupName(Q_UINT16 id)
+{
+	for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID==id)
+		{	
+			return groupList.at(t)->name;
+		}
+	}
+	return QString("");
+}
+QString kxContact::getGroupNameByID(Q_UINT16 id)
+{
+	for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID==id)
+		{	
+			return groupList.at(t)->name;
+		}
+	}
+	return QString("");
+}
+Q_UINT16 kxContact::getGroupID(Q_UINT16 _num)
+{
+	return groupList.at(_num)->groupID;
+}
+Q_UINT16 kxContact::getGroupCount()
+{
+	return groupList.count();
+}
+void kxContact::loadGroups()
+{
+	contactsFile->setGroup("Default");
+	
+	QStrList nameList, numList;
+ 	contactsFile->readListEntry("Group Names",nameList);
+ 	contactsFile->readListEntry("Group IDs",numList);
+ 	groupIDCount=contactsFile->readNumEntry("Group ID Count",0);
+ 	
+ 	for (Q_UINT16 t=0; t<nameList.count(); t++)
+ 	{
+ 		kxGroupStruct *c;
+ 		c=new kxGroupStruct;
+ 		c->name=QString::fromUtf8(nameList.at(t));
+ 		c->groupID=QString(numList.at(t)).toUInt();
+   	QString str;
+   	str.sprintf("Group %d",c->groupID);
+   	contactsFile->setGroup(str);
+ 		c->open=contactsFile->readBoolEntry("Open",FALSE);
+ 		groupList.append(c);
+ 	} 		
+}
+void kxContact::setGroupOpen(Q_UINT16 _id, bool _open)
+{
+	if (_id==0 || _id==999 || _id==998)
+	{
+		contactsFile->setGroup("Groups");
+		if (_id==0)
+			contactsFile->writeEntry("Default Open", _open);
+		else if (_id==999)
+			contactsFile->writeEntry("Wait Authorization Open", _open);
+		else if (_id==998)
+			contactsFile->writeEntry("Non ICQ Open", _open);
+			
+		contactsFile->sync();			
+	}
+	else for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID==_id)
+		{	
+			groupList.at(t)->open=_open;
+	   	QString str;
+    	str.sprintf("Group %d",_id);
+    	contactsFile->setGroup(str);
+    	contactsFile->writeEntry("Open", _open);
+			contactsFile->sync();    	  		
+			return;
+		}
+	}	
+}
+kxGroupStruct kxContact::getGroupStructByID(Q_UINT16 _id)
+{
+	if (_id==0 || _id==999 || _id==998)
+	{
+		bool open=FALSE;
+		contactsFile->setGroup("Groups");
+		if (_id==0)
+			open=contactsFile->readBoolEntry("Default Open", TRUE);
+		else if (_id==999)
+			open=contactsFile->readBoolEntry("Wait Authorization Open", FALSE);
+		else if (_id==998)
+			open=contactsFile->readBoolEntry("Non ICQ Open", FALSE);
+		
+		kxGroupStruct c;
+		c.groupID=_id;
+		c.open=open;
+		return c;			
+	}
+	for (Q_UINT16 t=0; t<groupList.count(); t++)
+	{
+		if (groupList.at(t)->groupID==_id)
+		{
+			return *groupList.at(t);
+		}
+	}
+	kxGroupStruct c;
+	c.groupID=0;
+	c.open=FALSE;
+	return c;
+}
