@@ -1,28 +1,32 @@
 #include "kxfile.h"
 #include <kxengine.h>
 #include <kxcontact.h>
+#include <stdlib.h>
 #include <kxtcp.h>
 
-kxFile::kxFile(UIN _uin, kxServerSocket *_sock, int _port, int _type,QString _filename, int _size, int _seq) :  QObject(), kxPacket()
+kxFile::kxFile(UIN _uin, KServerSocket *_sock, int _port, int _type,QString _filename, int _size, int _seq) :  QObject(), kxPacket()
 {
   fileName=_filename;
   fileLen=_size;
   uin=_uin;
   port=_port;
   fileXSock=_sock;
+  fileSock=NULL;
  	initPacket();	
   fileBatch.setAutoDelete(TRUE);
   packetList.setAutoDelete(TRUE);
   type=_type;
   sendDone=FALSE;
+  session_id=0;
+  doAck=FALSE;
   
   switch(type)
   {
     case GOT_FILE:
       debug("connect..");    
-      QObject::connect(fileXSock,SIGNAL(accepted(kxSocket *)), this, SLOT(SlotAccepted(kxSocket *)));
+      QObject::connect(fileXSock,SIGNAL(accepted(KSocket *)), this, SLOT(SlotAccepted(KSocket *)));
       debug("send accept..");
-      ENGINE->TCP->sendFileAccept(uin,_seq,fileXSock->getPort());
+      ENGINE->TCP->sendFileAccept(uin,_seq,fileXSock->port());
       file=NULL;
       break;
     case SEND_FILE:
@@ -35,7 +39,8 @@ kxFile::kxFile(UIN _uin, kxServerSocket *_sock, int _port, int _type,QString _fi
 			else
 			{
 				sendHandshake();
-				sendClientInit();
+				handshakeStatus=kxTCP::SEND_WAIT_ACK;
+//				sendClientInit();
 			}
       break;
   }  
@@ -50,14 +55,14 @@ int kxFile::doConnect()
 	if (p.intIp) debug("Use Internal IP ! %d",p.realIp);
 	if (p.intIp) ip=p.realIp; else ip=p.ip;
 	Q_UINT32 l=icqToIp(ip);
-	fileSock=new kxSocket(l, port);
-	debug("new kxSocket");
+	fileSock=new KSocket(QString("%1.%2.%3.%4").arg(l & 0xFF).arg((l>>8) & 0xFF).arg((l>>16) & 0xFF).arg(l>>24).latin1(), port);
+	debug("new KSocket");
 	if (fileSock->socket()!=-1)
 	{
 		fileSock->enableRead(TRUE);
-		QObject::connect(fileSock,SIGNAL(readEvent(kxSocket *)), this, SLOT(SlotReadEvent(kxSocket *)));
-		QObject::connect(fileSock,SIGNAL(closeEvent(kxSocket *)), this, SLOT(SlotCloseEvent(kxSocket *)));
-		QObject::connect(fileSock,SIGNAL(writeEvent(kxSocket *)), this, SLOT(SlotWriteEvent(kxSocket *)));
+		QObject::connect(fileSock,SIGNAL(readEvent(KSocket *)), this, SLOT(SlotReadEvent(KSocket *)));
+		QObject::connect(fileSock,SIGNAL(closeEvent(KSocket *)), this, SLOT(SlotCloseEvent(KSocket *)));
+		QObject::connect(fileSock,SIGNAL(writeEvent(KSocket *)), this, SLOT(SlotWriteEvent(KSocket *)));
 		emit SignalGotConnection();
 		return fileSock->socket(); 		
 	}
@@ -72,13 +77,13 @@ int kxFile::doConnect()
 	return -1;
 }
 
-void kxFile::SlotAccepted(kxSocket *_ks)
+void kxFile::SlotAccepted(KSocket *_ks)
 {
   debug("Connected...FileX");
- 	QObject::connect(_ks,SIGNAL(readEvent(kxSocket *)), this, SLOT(SlotReadEvent(kxSocket *)));
-	QObject::connect(_ks,SIGNAL(closeEvent(kxSocket *)), this, SLOT(SlotCloseEvent(kxSocket *)));
-	QObject::connect(_ks,SIGNAL(writeEvent(kxSocket *)), this, SLOT(SlotWriteEvent(kxSocket *)));
-	QObject::disconnect(fileXSock,SIGNAL(accepted(kxSocket *)), this, SLOT(SlotAccepted(kxSocket *)));
+ 	QObject::connect(_ks,SIGNAL(readEvent(KSocket *)), this, SLOT(SlotReadEvent(KSocket *)));
+	QObject::connect(_ks,SIGNAL(closeEvent(KSocket *)), this, SLOT(SlotCloseEvent(KSocket *)));
+	QObject::connect(_ks,SIGNAL(writeEvent(KSocket *)), this, SLOT(SlotWriteEvent(KSocket *)));
+	QObject::disconnect(fileXSock,SIGNAL(accepted(KSocket *)), this, SLOT(SlotAccepted(KSocket *)));
 	fileSock=_ks;
 	fileSock->enableRead(TRUE);
 	if (fileXSock)
@@ -89,7 +94,7 @@ void kxFile::SlotAccepted(kxSocket *_ks)
 	emit SignalGotConnection();
 }
 
-void kxFile::SlotReadEvent(kxSocket *_ks)
+void kxFile::SlotReadEvent(KSocket *_ks)
 {
   debug("read");
 	kxIncommingPacket *p;
@@ -163,7 +168,13 @@ void kxFile::parseData(QByteArray *a, int len)
     QDataStream s( *a, IO_ReadOnly );            // open on a's data
 		s.setByteOrder(QDataStream::LittleEndian);	
 
-  	
+	Q_UINT32 uin, ip, ip2, port, seq=0x0, hversion=0, rport;
+	Q_UINT16 version , command, unknown_1, length;
+	Q_UINT16 status, commandType;
+	Q_UINT32 chatPort;
+	Q_UINT8 tmp;
+		
+		  	
     Q_UINT8 type;
     
     s >> (Q_UINT8  &) type;
@@ -191,11 +202,70 @@ void kxFile::parseData(QByteArray *a, int len)
   	switch(type) //status)
   	{
   	  case 0xFF: // handshake
-  	    debug("Got File Handshake, ignore");
-  	    break;
+  	  {
+       	debug("Got File Handshake, ignore ??");
+    		if (handshakeStatus==kxTCP::SEND_WAIT_HANDSHAKE)
+    	 	{
+    	 	 		debug("Ok, have REVERSE !!");
+    	 	 		handshakeStatus=kxTCP::RECEIVED;
+    	 	 		sendHandshake_Ack(uin);
+    	 	 		sendClientInit();
+//GO    	 	 		emit receivedHandshakeAck(uin);
+    	 	 		return;
+    	 	}
+     		s >> (Q_UINT16 &)hversion;
+     		switch(hversion)
+     		{
+     			case 2:
+     			case 3:
+     			case 4:
+     			case 5:
+     			{
+     			Q_UINT16 u16;
+          	   s >> (Q_UINT16 &)u16;			
+         		s >> (Q_UINT32 &)port;
+         		s >> (Q_UINT32 &)uin;
+         		s >> (Q_UINT32 &)ip;
+         		s >> (Q_UINT32 &)ip2;
+         		s >> (Q_UINT8  &)tmp;
+         		s >> (Q_UINT32 &)rport;		
+        		}
+        		break;
+           case 6:
+           case 7:
+           {
+           	Q_UINT16 u16;
+           	Q_UINT32 u32, ruin;
+          	   s >> (Q_UINT16 &)u16;
+         		s >> (Q_UINT32 &)ruin;
+         		s >> (Q_UINT16 &)u16;    		
+         		s >> (Q_UINT32 &)port;
+         		s >> (Q_UINT32 &)uin;
+         		s >> (Q_UINT32 &)ip;
+         		s >> (Q_UINT32 &)ip2;
+         		s >> (Q_UINT8  &)tmp;
+         		s >> (Q_UINT32 &)rport;
+         		s >> (Q_UINT32 &)u32;		
+         		s >> (Q_UINT32 &)u32;
+         		s >> (Q_UINT32 &)u32; 		
+           }
+         }   		
+         debug("VErsion: %d",hversion);
+      	  if ((hversion==6 || hversion==7))
+      	  {
+ 	     	  	debug("V6 or V7 send Ack !");
+       	 	  sendHandshake_Ack(uin);
+       	 	  debug("Ack send..");
+       	 	  handshakeStatus=kxTCP::RECEIVE_WAIT_ACK;
+       	 	  debug("Now send handshake");
+       	 	  sendHandshake();	
+       	 	  debug("Handshake send..");	 	 	
+   		  }
+      }
+      break;
   	  case 0x00: // packet 0
   	  {
-  	    debug("Got File Packet 0");  
+  	    debug("Got File Packet 0");
   	      Q_UINT32 junk;
   	      Q_UINT32 total, batchLen, speed;
   	      Q_UINT16 flen;
@@ -213,13 +283,27 @@ void kxFile::parseData(QByteArray *a, int len)
     	    batchNum=0;
           emit SignalProcessInit(batchLen, total);
     	    sendServerInit();
+    	
   	    break;
   	  }
   	  case 0x01: // packet 0
   	  {
-  	    debug("Got File Packet 1");  
-        emit SignalServerInfo(file->size(), 1, QString(fileName), QString("")); // total Size, total Files, localname, remote name
-  	    sendBatchInfo();
+  	    debug("Got File Packet 1");
+  	     if (handshakeStatus==kxTCP::RECEIVE_WAIT_ACK)
+  	     {
+  	     	  debug("Oops, is return Handshake..");
+  	     	  handshakeStatus=kxTCP::RECEIVED;
+  	     }
+  	     else
+  	     if (handshakeStatus==kxTCP::SEND_WAIT_ACK)
+  	     {
+  	     		handshakeStatus=kxTCP::SEND_WAIT_HANDSHAKE;
+  	     }
+  	     else
+  	     {  	
+	          emit SignalServerInfo(file->size(), 1, QString(fileName), QString("")); // total Size, total Files, localname, remote name
+	  	      sendBatchInfo();
+  			  }
   	    break;
   	  }
   	  case 0x02: // packet 0
@@ -321,7 +405,7 @@ void kxFile::parseData(QByteArray *a, int len)
 }
 
 /**  */
-void kxFile::SlotCloseEvent(kxSocket *_ks){
+void kxFile::SlotCloseEvent(KSocket *_ks){
 	debug("delete _ks !");
 	if (fileXSock)
 	  delete fileXSock;
@@ -337,7 +421,7 @@ void kxFile::SlotCloseEvent(kxSocket *_ks){
 }
 
 /**  */
-void kxFile::SlotWriteEvent(kxSocket *_ks)
+void kxFile::SlotWriteEvent(KSocket *_ks)
 {
   debug("write");
 	if (!fileSock) { debug("can not send"); return; }
@@ -391,9 +475,9 @@ void kxFile::SlotWriteEvent(kxSocket *_ks)
           emit SignalSendOk();
 		      if (fileSock)
           {
-           	QObject::disconnect(fileSock,SIGNAL(readEvent(kxSocket *)), this, SLOT(SlotReadEvent(kxSocket *)));
-          	QObject::disconnect(fileSock,SIGNAL(closeEvent(kxSocket *)), this, SLOT(SlotCloseEvent(kxSocket *)));
-        	  QObject::disconnect(fileSock,SIGNAL(writeEvent(kxSocket *)), this, SLOT(SlotWriteEvent(kxSocket *)));
+           	QObject::disconnect(fileSock,SIGNAL(readEvent(KSocket *)), this, SLOT(SlotReadEvent(KSocket *)));
+          	QObject::disconnect(fileSock,SIGNAL(closeEvent(KSocket *)), this, SLOT(SlotCloseEvent(KSocket *)));
+        	  QObject::disconnect(fileSock,SIGNAL(writeEvent(KSocket *)), this, SLOT(SlotWriteEvent(KSocket *)));
             delete fileSock;
             fileSock=NULL;
           }
@@ -416,10 +500,11 @@ void kxFile::sendStartFile(int pos,int num)
 	
   s << ( Q_UINT8  ) packet;
   s << ( Q_UINT32 ) len;
-  s << ( Q_UINT32 ) X1;
-  s << ( Q_UINT32 ) speed;  
+  s << ( Q_UINT32 ) 0x00;
+  s << ( Q_UINT32 ) speed;
+  s << ( Q_UINT32 ) num;
   
-  length=13;
+  length=1+4+4+4+4;
   
 	addPacket2List(fileSock, uin);
 
@@ -432,7 +517,7 @@ void kxFile::sendServerInit()
 	s.setByteOrder(QDataStream::LittleEndian);
 	
 	Q_UINT8 junk=1;
-	Q_UINT32 junk2= 0x64;
+	Q_UINT32 junk2= 0x0;
 	Q_UINT16 len=fileName.length()+1;
 	
   s << ( Q_UINT8  ) junk;
@@ -444,7 +529,8 @@ void kxFile::sendServerInit()
   
 	addPacket2List(fileSock, uin);
 
-	fileSock->enableWrite(TRUE);   	
+	fileSock->enableWrite(TRUE);
+	changeSpeed(0x64); 	
 }
 void kxFile::sendHandshake()
 {
@@ -452,25 +538,70 @@ void kxFile::sendHandshake()
 	QDataStream s(*byteArray, IO_ReadWrite);
 	s.setByteOrder(QDataStream::LittleEndian);
 
-	Q_UINT32 ip=ipToIcq(ENGINE->ourExtIP), lip=ipToIcq(ENGINE->ourIntIP), _port=ENGINE->ourPort, uin=ENGINE->ourUin;
+	Q_UINT32 ip=ipToIcq(ENGINE->ourExtIP), lip=ipToIcq(ENGINE->ourIntIP),  ouin=ENGINE->ourUin;
 	Q_UINT32 chatPort=port;
-	Q_UINT16 version =0x02;
-  Q_UINT16 mac =0x00;	 
-	Q_UINT8 hs=0xff, tcpc=0x04;	
+	Q_UINT16 version =0x06;
+  Q_UINT16 zero=0x00;	
+	Q_UINT8 hs=0xff, mode=0x04;	
 
-	s << ( Q_UINT8  ) hs;
-	s << ( Q_UINT16 ) version;
-  s << ( Q_UINT16 ) mac;		
-	s << ( Q_UINT32 ) _port;
-	s << ( Q_UINT32 ) ENGINE->ourUin;
-	s << ( Q_UINT32 ) ip;	
-	s << ( Q_UINT32 ) lip;		
-	s << ( Q_UINT8  ) tcpc;
-	s << ( Q_UINT32 ) chatPort;	
-	
-//	debug("ack Packet to send: command: %Xd (%d)",command,command);
+	switch(contacts->getContact(uin).tcpVersion)
+	{
+		case 2:
+		case 3:
+  	case 4:
+		case 5:
+			{
+				version=0x0002;
+      	s << ( Q_UINT8  ) hs;
+      	s << ( Q_UINT16 ) version;	
+       	s << ( Q_UINT16 ) zero;
+      	s << ( Q_UINT32 ) port;
+      	s << ( Q_UINT32 ) ouin;
+      	s << ( Q_UINT32 ) ip;	
+      	s << ( Q_UINT32 ) lip;		
+      	s << ( Q_UINT8  ) mode;
+      	s << ( Q_UINT32 ) chatPort;	
+      	
+      	//	debug("ack Packet to send: command: %Xd (%d)",command,command);
+				doAck=TRUE;
+      	length=1+2+2+4+4+4+4+1+4;
+       }		
+			break;
+   case 6:
+   case 7:
+   		{
+   			version=0x0006;
+   			zero=0x0;
+   			hs=0xFF;
+        Q_UINT32 c1=0x00000050;
+        Q_UINT32 c2=0x00000003;   			
+        if (session_id==0)
+        {
+        	session_id=rand();
+        	debug("session: %d",session_id);
+        }
+   			s << ( Q_UINT8  ) hs;
+   			s << ( Q_UINT32 ) version;
+   			s << ( Q_UINT32 ) uin;
+				s << ( Q_UINT16 ) zero;
+				s << ( Q_UINT32 ) port;
+				s << ( Q_UINT32 ) ouin;
+      	s << ( Q_UINT32 ) lip;	
+      	s << ( Q_UINT32 ) ip;		
+      	s << ( Q_UINT8  ) mode;
+      	s << ( Q_UINT32 ) port;					
+        s << ( Q_UINT32 ) session_id;
+        s << ( Q_UINT32 ) c1;
+        s << ( Q_UINT32 ) c2;
 
-	length=1+2+2+4+4+4+4+1+4;
+        length=44;
+
+
+      //  kxEncryptClient(byteArray, length, 0x06);   				   			
+   			
+   		}
+   		break;
+  } 	
 	addPacket2List(fileSock, uin);
 
 	fileSock->enableWrite(TRUE);   	
@@ -483,7 +614,7 @@ void kxFile::sendClientInit() //packet 0
 	s.setByteOrder(QDataStream::LittleEndian);
 	
 	Q_UINT8 junk=0;
-	Q_UINT32 junk2=0, speed=0x0, numfiles=1;
+	Q_UINT32 junk2=0, speed=0x64, numfiles=1;
 	Q_UINT16 len=fileName.length()+1;
 	Q_UINT32 size=0;
 	if (file) size=file->size();
@@ -594,3 +725,29 @@ void kxFile::closeNow()
   if (fileSock) delete fileSock;
   if (fileXSock) delete fileXSock;
 }
+void kxFile::sendHandshake_Ack(UIN _ruin)
+{
+	debug("Send Handshake Ack");
+	QDataStream s(*byteArray, IO_ReadWrite);
+	s.setByteOrder(QDataStream::LittleEndian);
+	Q_UINT32 ok=0x01;
+	s << (Q_UINT32 ) ok;
+	length=4;
+	addPacket2List(fileSock, _ruin);
+	fileSock->enableWrite(TRUE);   	
+
+}
+
+/** Change speed of File transfer */
+void kxFile::changeSpeed(int speed)
+{
+	debug("Send Speed Change");
+	QDataStream s(*byteArray, IO_ReadWrite);
+	s.setByteOrder(QDataStream::LittleEndian);
+	Q_UINT32 ok=speed;
+	s << (Q_UINT8  ) 0x05;
+	s << (Q_UINT32 ) ok;
+	length=5;
+	addPacket2List(fileSock, uin);
+	fileSock->enableWrite(TRUE);
+}
