@@ -5,6 +5,7 @@
 #include "kxengine.h"
 #include <kxcontact.h>
 #include <kstddirs.h>
+#include <qstringlist.h>
 
 kxMessage::kxMessage()
 {
@@ -48,6 +49,7 @@ void kxMessage::readMessages()
         info->read=val.mid(0,1).toInt();
         info->type=val.mid(2,2).toInt();
         info->send=val.mid(5,2).toInt();
+        info->useColor=FALSE;
         info->pos=pos;
         buf=t.readLine();
         split(buf,&key, &val);
@@ -92,6 +94,7 @@ void kxMessage::split(QString str, QString *key, QString *val)
   
 void kxMessage::newMessage(UIN _uin,  kxMessageStruct _msg)
 {
+	if ((ENGINE->ignoreMessage && ENGINE->CONTACT->getContact(_uin).uin==0)  || (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
   file.at(0);
   QString size;
   int num=messageList.count()+1;
@@ -107,6 +110,10 @@ void kxMessage::newMessage(UIN _uin,  kxMessageStruct _msg)
   info->read=_msg.send==TRUE ? TRUE : FALSE;
   info->type=MESSAGE_TYPE;
   info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
   
   messageList.append(info);
   int p=messageList.at();
@@ -142,7 +149,7 @@ void kxMessage::newMessage(UIN _uin,  kxMessageStruct _msg)
 }
 void kxMessage::newUrl(UIN _uin,  kxMessageStruct _msg)
 {
-  debug("New Message: %d, [%s]",_uin, _msg.message.latin1());
+	if ((ENGINE->ignoreUrl && ENGINE->CONTACT->getContact(_uin).uin==0)  || (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
   file.at(0);
   QString size;
   int num=messageList.count()+1;
@@ -158,6 +165,10 @@ void kxMessage::newUrl(UIN _uin,  kxMessageStruct _msg)
   info->read=_msg.send==TRUE ? TRUE : FALSE;
   info->type=URL_TYPE;
   info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
   
   messageList.append(info);
   if (!_msg.send) ENGINE->CONTACT->addMessage(_uin);
@@ -189,6 +200,7 @@ void kxMessage::newUrl(UIN _uin,  kxMessageStruct _msg)
 }
 void kxMessage::newAuthReq(UIN _uin,  kxMessageStruct _msg)
 {
+//	if ((ENGINE->ignoreRest && ENGINE->CONTACT->getContact(_uin).uin==0)  ||  (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
   file.at(0);
   QString size;
   int num=messageList.count()+1;
@@ -204,6 +216,10 @@ void kxMessage::newAuthReq(UIN _uin,  kxMessageStruct _msg)
   info->read=_msg.send==TRUE ? TRUE : FALSE;
   info->type=REQUEST_TYPE;
   info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
   
   messageList.append(info);
   int p=messageList.at();
@@ -241,8 +257,65 @@ void kxMessage::newAuthReq(UIN _uin,  kxMessageStruct _msg)
   emit SignalMessagePos(info->uin,p);
   
 }
+void kxMessage::newAuthReply(UIN _uin,  kxMessageStruct _msg)
+{
+//	if ((ENGINE->ignoreRest && ENGINE->CONTACT->getContact(_uin).uin==0)  ||  (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
+  file.at(0);
+  QString size;
+  int num=messageList.count()+1;
+  size=makeMessageCount(num);
+  QTextStream tw ( &file );
+  tw << size;
+  file.at(file.size());
+  QTextStream t ( &file );
+  kxMessageInfoStruct *info;
+  info=new kxMessageInfoStruct;
+  info->uin=_uin;
+  info->pos=file.at();
+  info->read=_msg.send==TRUE ? TRUE : FALSE;
+  info->type=_msg.type;
+  info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
+
+  messageList.append(info);
+  int p=messageList.at();
+
+  QString buf;
+
+  buf.sprintf("[Message %d]\n",num);
+  t << buf;
+  buf.sprintf("Options=%01d %02d %01d %01d %01d 0\n",info->read, _msg.type, info->send, _msg.online, _msg.auth_request );
+  t << buf;
+  buf.sprintf("Uin=%d\n",_uin);
+  t << buf;
+  buf.sprintf("DateTime=%02d-%02d-%04d %02d:%02d\n",_msg.dateTime.date().day()
+                                                   ,_msg.dateTime.date().month()
+                                                   ,_msg.dateTime.date().year()
+                                                   ,_msg.dateTime.time().hour()
+                                                   ,_msg.dateTime.time().minute() );
+  t << buf;
+
+  _msg.message.replace(QRegExp("\n"),"\\n");
+  _msg.message.replace(QRegExp("\r"),"\\r");
+
+  t << "Message="+_msg.message+"\n";
+
+  file.flush();
+  if (!_msg.send)
+  {
+    ENGINE->CONTACT->addMessage(_uin);
+    emit SignalMessagePosSend(info->uin,p);
+  }
+  emit SignalMessagePos(info->uin,p);
+
+}
+
 void kxMessage::newAdded(UIN _uin,  kxMessageStruct _msg)
 {
+//	if ((ENGINE->ignoreRest && ENGINE->CONTACT->getContact(_uin).uin==0) ||  (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
   file.at(0);
   QString size;
   int num=messageList.count()+1;
@@ -258,6 +331,9 @@ void kxMessage::newAdded(UIN _uin,  kxMessageStruct _msg)
   info->read=_msg.send==TRUE ? TRUE : FALSE;
   info->type=ADDED_TYPE;
   info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
   
   messageList.append(info);
   int p=messageList.at();
@@ -277,7 +353,6 @@ void kxMessage::newAdded(UIN _uin,  kxMessageStruct _msg)
                                                    ,_msg.dateTime.time().minute() );
   t << buf;
 
-  
   t << "Nick="+_msg.nick+"\n";
   t << "FirstName="+_msg.firstName+"\n";
   t << "LastName="+_msg.lastName+"\n";
@@ -292,10 +367,131 @@ void kxMessage::newAdded(UIN _uin,  kxMessageStruct _msg)
   emit SignalMessagePos(info->uin,p);
 
 }
-
-
-kxMessageStruct kxMessage::getMessage(int _pos)
+void kxMessage::newContacts(UIN _uin,  kxMessageStruct _msg)
 {
+	if ((ENGINE->ignoreRest && ENGINE->CONTACT->getContact(_uin).uin==0)   || (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
+  file.at(0);
+  QString size;
+  int num=messageList.count()+1;
+  size=makeMessageCount(num);
+  QTextStream tw ( &file );
+  tw << size;
+  file.at(file.size());
+  QTextStream t ( &file );
+  kxMessageInfoStruct *info;
+  info=new kxMessageInfoStruct;
+  info->uin=_uin;
+  info->pos=file.at();
+  info->read=_msg.send==TRUE ? TRUE : FALSE;
+  info->type=CONTACTS_TYPE;
+  info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
+
+  messageList.append(info);
+  int p=messageList.at();
+
+  QString buf;
+
+  buf.sprintf("[Message %d]\n",num);
+  t << buf;
+  buf.sprintf("Options=%01d %02d %01d %01d %01d 0\n",info->read, _msg.type, info->send, _msg.online, _msg.auth_request );
+  t << buf;
+  buf.sprintf("Uin=%d\n",_uin);
+  t << buf;
+  buf.sprintf("DateTime=%02d-%02d-%04d %02d:%02d\n",_msg.dateTime.date().day()
+                                                   ,_msg.dateTime.date().month()
+                                                   ,_msg.dateTime.date().year()
+                                                   ,_msg.dateTime.time().hour()
+                                                   ,_msg.dateTime.time().minute() );
+  t << buf;
+  QString lst="ContactList=";
+  for (Q_UINT16 t=0; t<_msg.list.count(); t++)
+  {
+  	QString _lst;
+  	_lst.sprintf("%d,%s,",_msg.list.at(t)->uin,_msg.list.at(t)->nick.latin1());
+  	lst+=_lst;
+  }
+  lst+="\n";
+  t << lst;
+  _msg.list.clear();
+
+  file.flush();
+  if (!_msg.send)
+  {
+    ENGINE->CONTACT->addMessage(_uin);
+    emit SignalMessagePosSend(info->uin,p);
+  }
+  emit SignalMessagePos(info->uin,p);
+
+}
+void kxMessage::newSMSReply(UIN _uin,kxMessageStruct _msg)
+{
+// not needed for SMS	if ((ENGINE->ignoreRest && ENGINE->CONTACT->getContact(_uin).uin==0)   || (ENGINE->CONTACT->getContact(_uin).uin>0 && ENGINE->CONTACT->getContact(_uin).ignore)) return;
+  file.at(0);
+  QString size;
+  int num=messageList.count()+1;
+  size=makeMessageCount(num);
+  QTextStream tw ( &file );
+  tw << size;
+  file.at(file.size());
+  QTextStream t ( &file );
+  kxMessageInfoStruct *info;
+  info=new kxMessageInfoStruct;
+  info->uin=_uin;
+  info->pos=file.at();
+  info->read=_msg.send==TRUE ? TRUE : FALSE;
+  info->type=SMS_TYPE;
+  info->send=_msg.send;
+  info->useColor=_msg.useColor;
+	info->foreground=_msg.foreground;
+	info->background=_msg.background;
+
+  messageList.append(info);
+  int p=messageList.at();
+
+  QString buf;
+
+  buf.sprintf("[Message %d]\n",num);
+  t << buf;
+  buf.sprintf("Options=%01d %02d %01d %01d %01d 0\n",info->read, _msg.type, info->send, _msg.online, _msg.auth_request );
+  t << buf;
+  buf.sprintf("Uin=%d\n",_uin);
+  t << buf;
+  buf.sprintf("DateTime=%02d-%02d-%04d %02d:%02d\n",_msg.dateTime.date().day()
+                                                   ,_msg.dateTime.date().month()
+                                                   ,_msg.dateTime.date().year()
+                                                   ,_msg.dateTime.time().hour()
+                                                   ,_msg.dateTime.time().minute() );
+  t << buf;
+  _msg.message.replace(QRegExp("\n"),"\\n");
+  _msg.message.replace(QRegExp("\r"),"\\r");
+
+  t << "Message="+_msg.message+"\n";
+
+  file.flush();
+  if (!_msg.send)
+  {
+    ENGINE->CONTACT->addMessage(_uin);
+    emit SignalMessagePosSend(info->uin,p);
+  }
+  emit SignalMessagePos(info->uin,p);
+}
+
+kxMessageInfoStruct *kxMessage::getMessageInfo(int _pos)
+{
+	return messageList.at(_pos);
+}
+kxMessageStruct kxMessage::getMessage(int _pos, bool del=TRUE)
+{
+	if (_pos<0)
+	{
+		kxMessageStruct message;
+		message.uin=0;
+		return message;
+	}
   int pos=messageList.at(_pos)->pos;
   file.at(pos);
   QTextStream t ( &file );
@@ -303,6 +499,9 @@ kxMessageStruct kxMessage::getMessage(int _pos)
   QString key,val;
   kxMessageStruct message;
   message.uin=0;
+  message.useColor=messageList.at(_pos)->useColor;
+	message.foreground=messageList.at(_pos)->foreground;
+	message.background=messageList.at(_pos)->background;
 
   buf=t.readLine();
   buf=t.readLine();
@@ -340,7 +539,9 @@ kxMessageStruct kxMessage::getMessage(int _pos)
     message.dateTime.setDate(date);
     message.dateTime.setTime(time);
 
-    if (message.type==MESSAGE_TYPE || message.type==URL_TYPE || message.type==REQUEST_TYPE)
+    if (message.type==MESSAGE_TYPE || message.type==URL_TYPE || message.type==REQUEST_TYPE
+        || message.type==AUTH_TYPE || message.type==REJECT_TYPE || message.type==SMS_TYPE
+    		)
     {
       buf=t.readLine();
       split(buf,&key, &val);      
@@ -368,7 +569,26 @@ kxMessageStruct kxMessage::getMessage(int _pos)
       buf=t.readLine();
       split(buf,&key, &val);
       message.email=val;    
-    }      
+    }
+    if (message.type==CONTACTS_TYPE)
+    {
+    	if (!del) //do get the list !
+    	{
+      	buf=t.readLine();
+      	split(buf,&key, &val);
+      	kxAddContactStruct *c;
+      	QStringList lst=QStringList::split(',',val);
+      	for ( QStringList::Iterator it = lst.begin(); it != lst.end(); ++it )
+      	{
+      		c=new kxAddContactStruct;
+      		c->uin=(*it).toUInt();
+      		++it;
+          c->nick=(*it);
+
+          message.list.append(c);
+        }    	
+      }
+    }
   }
   return message;
 }
