@@ -17,13 +17,14 @@ class kxSend : public QObject
 {
   Q_OBJECT
 public:
-  kxSend(int, int, UIN, QString, QString, bool);
+  kxSend(int, int, UIN, QString, QString, bool, QColor _fg, QColor _bg,  bool _useColor=FALSE);
   kxSend(int, UIN, QList<kxAddContactStruct> *, bool);
   
   QTimer sendTimer;
   kxMessageStruct message;
   int sendAck;
   int sendSeq;
+  bool send;
   QList<kxAddContactStruct> *contactList;
   
   int type; // 1 = UDP, 0 = TCP;
@@ -36,7 +37,10 @@ public:
   
 public slots:
   void SlotTimeout();
-  void SlotReceivedAck(int); 
+  void SlotReceivedAck(Q_UINT16);
+  void SlotReceivedErrorAck(Q_UINT16, Q_UINT16);
+
+  void SlotSendToClient(UIN);
   
 signals:
   void SignalSendToClientError(int);
