@@ -21,11 +21,14 @@ public:
 
   QTimer blinkTimer;  
   QPixmap pixmap;
-  QPoint Mpos;
-  QSize Msize;
+
+  QString status;
+  QString message;
+  int icon;
   bool showIcon;
   
   int showMessage();
+  void paintWM();
   
 public slots:
   void SlotTimeout();
