@@ -8,7 +8,7 @@
 #include <kanimwidget.h>
 #include <v2_codes.h>
 #include "kxfiledialog.h"
-#include <kxsock.h>
+#include <ksock.h>
 #include <kxfile.h>
 #include <qstring.h>
 #include <qobject.h>
@@ -18,7 +18,7 @@ class kxFileDialogImpl : public kxFileDialog
 {
   Q_OBJECT
 public:
-  kxFileDialogImpl(UIN,kxServerSocket *, QString, int,int, QWidget* parent,  
+  kxFileDialogImpl(UIN,KServerSocket *, QString, int,int, QWidget* parent,
     const char* name = 0, int _seq=0);
   
   ~kxFileDialogImpl() {};
@@ -26,7 +26,7 @@ public:
   kxFile *fileEngine;
   int port;
   int type;
-  kxServerSocket *sock;
+  KServerSocket *sock;
   QString fileName;
   int size;
   UIN uin;
