@@ -43,12 +43,43 @@ void kxLabel::paintEvent(QPaintEvent *_p)
 
   int x=0;
   QPixmap pixmap;
-  
+
+  switch(ENGINE->currentStatus)
+  {
+    case STATUS_OFFLINE: 			
+      pixmap=MAINWINDOW->kxIcons.offline; 	
+	  	break;
+    case STATUS_DND: 			
+      pixmap=MAINWINDOW->kxIcons.dnd; 	
+	  	break;
+	  case STATUS_OCCUPIED: 	
+      pixmap=MAINWINDOW->kxIcons.occupied;
+	  	break;
+	  case STATUS_NA: 				
+	  	pixmap=MAINWINDOW->kxIcons.na; 	
+	  	break;
+	  case STATUS_AWAY: 			
+	  	pixmap=MAINWINDOW->kxIcons.away; 	
+	  	break;
+	  case STATUS_FFC: 			
+	  	pixmap=MAINWINDOW->kxIcons.ffc; 	
+	  	break;
+	  case STATUS_INVISIBLE:
+  	  pixmap=MAINWINDOW->kxIcons.invisible;
+  	  break;
+    case STATUS_ONLINE: 			
+    default:
+      pixmap=MAINWINDOW->kxIcons.online; 	
+	  	break;  	
+  }
+
   if (ENGINE->MESSAGE->countUnreadMessages(0)>0)
   {    
-    pixmap=MAINWINDOW->kxIcons.message;    
-    paint.drawPixmap((height()/2)-(pixmap.height()/2),2,pixmap);
-    x=pixmap.width();
+    pixmap=MAINWINDOW->kxIcons.message;
   }
+
+  paint.drawPixmap(3,(height()/2)-(pixmap.height()/2),pixmap);
+  x=pixmap.width();
+
   paint.drawText(x+3+2,(height()/2)-(fontMetrics().height()/2), width()-4, height()-2, AlignLeft, text.latin1());
-}
\ No newline at end of file
+}
