@@ -22,7 +22,7 @@ public:
 public slots:
   void SlotClicked(QListViewItem *);
 
-	void SlotSearchFound(Q_UINT16, UIN, const char *, const char *, const char *, const char *, Q_UINT8,Q_UINT16, bool);
+	void SlotSearchFound(Q_UINT16, UIN, QString,QString,QString,QString, Q_UINT8,Q_UINT8, bool);
 	void SlotSearchFailed(Q_UINT16);
 
   void SlotSearchButton();
