@@ -8,7 +8,7 @@ class kxStatusMessageDialogImpl : public kxStatusMessageDialog
     Q_OBJECT
 
 public:
-    kxStatusMessageDialogImpl( UIN, char *, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    kxStatusMessageDialogImpl( UIN, QString , QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
     kxStatusMessageDialogImpl( UIN, int,  QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
     ~kxStatusMessageDialogImpl();
     
